@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -50,7 +50,7 @@ from .type_defs import (
     TerminateTargetInstancesResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -62,7 +62,7 @@ __all__ = ("mgnClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -80,7 +80,7 @@ class Exceptions:
 
 class mgnClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html)
     """
 
@@ -96,7 +96,7 @@ class mgnClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#can_paginate)
         """
 
@@ -110,7 +110,7 @@ class mgnClient(BaseClient):
         Allows the user to set the SourceServer.LifeCycle.state property for specific
         Source Server IDs to one of the following: READY_FOR_TEST or READY_FOR_CUTOVER.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.change_server_life_cycle_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.change_server_life_cycle_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#change_server_life_cycle_state)
         """
 
@@ -124,17 +124,17 @@ class mgnClient(BaseClient):
         defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskTypeType,
         ebsEncryption: ReplicationConfigurationEbsEncryptionType,
         replicationServerInstanceType: str,
-        replicationServersSecurityGroupsIDs: List[str],
+        replicationServersSecurityGroupsIDs: Sequence[str],
         stagingAreaSubnetId: str,
-        stagingAreaTags: Dict[str, str],
+        stagingAreaTags: Mapping[str, str],
         useDedicatedReplicationServer: bool,
-        ebsEncryptionKeyArn: str = None,
-        tags: Dict[str, str] = None
+        ebsEncryptionKeyArn: str = ...,
+        tags: Mapping[str, str] = ...
     ) -> ReplicationConfigurationTemplateResponseMetadataTypeDef:
         """
         Creates a new ReplicationConfigurationTemplate.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.create_replication_configuration_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.create_replication_configuration_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#create_replication_configuration_template)
         """
 
@@ -142,7 +142,7 @@ class mgnClient(BaseClient):
         """
         Deletes a single Job by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.delete_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.delete_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_job)
         """
 
@@ -151,11 +151,11 @@ class mgnClient(BaseClient):
     ) -> Dict[str, Any]:
         """
         Deletes a single Replication Configuration Template by ID See also: `AWS API
-        Documentation <https://docs.aws.amazon.com/goto/WebAPI/mgn-2020-02-26/DeleteRepl
-        icationConfigurationTemplate>`_ **Request Syntax** response =
+        Documentation <https://docs.aws.amazon.com/goto/WebAPI/mgn-2020-02-
+        26/DeleteReplicationConfigurationTemplate>`_ **Request Syntax** response =
         client.delete_replication_configuration_template( replicatio...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.delete_replication_configuration_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.delete_replication_configuration_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_replication_configuration_template)
         """
 
@@ -163,17 +163,17 @@ class mgnClient(BaseClient):
         """
         Deletes a single source server by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.delete_source_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.delete_source_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#delete_source_server)
         """
 
     def describe_job_log_items(
-        self, *, jobID: str, maxResults: int = None, nextToken: str = None
+        self, *, jobID: str, maxResults: int = ..., nextToken: str = ...
     ) -> DescribeJobLogItemsResponseTypeDef:
         """
         Retrieves detailed Job log with paging.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.describe_job_log_items)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_job_log_items)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_job_log_items)
         """
 
@@ -181,27 +181,27 @@ class mgnClient(BaseClient):
         self,
         *,
         filters: "DescribeJobsRequestFiltersTypeDef",
-        maxResults: int = None,
-        nextToken: str = None
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> DescribeJobsResponseTypeDef:
         """
         Returns a list of Jobs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.describe_jobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_jobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_jobs)
         """
 
     def describe_replication_configuration_templates(
         self,
         *,
-        replicationConfigurationTemplateIDs: List[str],
-        maxResults: int = None,
-        nextToken: str = None
+        replicationConfigurationTemplateIDs: Sequence[str],
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> DescribeReplicationConfigurationTemplatesResponseTypeDef:
         """
         Lists all ReplicationConfigurationTemplates, filtered by Source Server IDs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.describe_replication_configuration_templates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_replication_configuration_templates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_replication_configuration_templates)
         """
 
@@ -209,13 +209,13 @@ class mgnClient(BaseClient):
         self,
         *,
         filters: "DescribeSourceServersRequestFiltersTypeDef",
-        maxResults: int = None,
-        nextToken: str = None
+        maxResults: int = ...,
+        nextToken: str = ...
     ) -> DescribeSourceServersResponseTypeDef:
         """
         Retrieves all SourceServers or multiple SourceServers by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.describe_source_servers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.describe_source_servers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#describe_source_servers)
         """
 
@@ -225,7 +225,7 @@ class mgnClient(BaseClient):
         """
         Disconnects specific Source Servers from Application Migration Service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.disconnect_from_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.disconnect_from_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#disconnect_from_service)
         """
 
@@ -233,21 +233,21 @@ class mgnClient(BaseClient):
         """
         Finalizes the cutover immediately for specific Source Servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.finalize_cutover)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.finalize_cutover)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#finalize_cutover)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#generate_presigned_url)
         """
 
@@ -255,7 +255,7 @@ class mgnClient(BaseClient):
         """
         Lists all LaunchConfigurations available, filtered by Source Server IDs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.get_launch_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.get_launch_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_launch_configuration)
         """
 
@@ -265,7 +265,7 @@ class mgnClient(BaseClient):
         """
         Lists all ReplicationConfigurations, filtered by Source Server ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.get_replication_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.get_replication_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#get_replication_configuration)
         """
 
@@ -273,7 +273,7 @@ class mgnClient(BaseClient):
         """
         Initialize Application Migration Service.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.initialize_service)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.initialize_service)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#initialize_service)
         """
 
@@ -281,7 +281,7 @@ class mgnClient(BaseClient):
         """
         List all tags for your Application Migration Service resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#list_tags_for_resource)
         """
 
@@ -290,7 +290,7 @@ class mgnClient(BaseClient):
         Archives specific Source Servers by setting the SourceServer.isArchived property
         to true for specified SourceServers by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.mark_as_archived)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.mark_as_archived)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#mark_as_archived)
         """
 
@@ -300,55 +300,55 @@ class mgnClient(BaseClient):
         Handshake for specified SourceServer IDs, regardless of when the previous
         initiation started.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.retry_data_replication)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.retry_data_replication)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#retry_data_replication)
         """
 
     def start_cutover(
-        self, *, sourceServerIDs: List[str], tags: Dict[str, str] = None
+        self, *, sourceServerIDs: Sequence[str], tags: Mapping[str, str] = ...
     ) -> StartCutoverResponseTypeDef:
         """
         Launches a Cutover Instance for specific Source Servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.start_cutover)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.start_cutover)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start_cutover)
         """
 
     def start_test(
-        self, *, sourceServerIDs: List[str], tags: Dict[str, str] = None
+        self, *, sourceServerIDs: Sequence[str], tags: Mapping[str, str] = ...
     ) -> StartTestResponseTypeDef:
         """
         Lauches a Test Instance for specific Source Servers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.start_test)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.start_test)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#start_test)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: Dict[str, str]) -> None:
+    def tag_resource(self, *, resourceArn: str, tags: Mapping[str, str]) -> None:
         """
         Adds or overwrites only the specified tags for the specified Application
         Migration Service resource or resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#tag_resource)
         """
 
     def terminate_target_instances(
-        self, *, sourceServerIDs: List[str], tags: Dict[str, str] = None
+        self, *, sourceServerIDs: Sequence[str], tags: Mapping[str, str] = ...
     ) -> TerminateTargetInstancesResponseTypeDef:
         """
         Starts a job that terminates specific launched EC2 Test and Cutover instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.terminate_target_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.terminate_target_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#terminate_target_instances)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> None:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> None:
         """
         Deletes the specified set of tags from the specified set of Application
         Migration Service resources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#untag_resource)
         """
 
@@ -356,17 +356,17 @@ class mgnClient(BaseClient):
         self,
         *,
         sourceServerID: str,
-        copyPrivateIp: bool = None,
-        copyTags: bool = None,
-        launchDisposition: LaunchDispositionType = None,
-        licensing: "LicensingTypeDef" = None,
-        name: str = None,
-        targetInstanceTypeRightSizingMethod: TargetInstanceTypeRightSizingMethodType = None
+        copyPrivateIp: bool = ...,
+        copyTags: bool = ...,
+        launchDisposition: LaunchDispositionType = ...,
+        licensing: "LicensingTypeDef" = ...,
+        name: str = ...,
+        targetInstanceTypeRightSizingMethod: TargetInstanceTypeRightSizingMethodType = ...
     ) -> LaunchConfigurationTypeDef:
         """
         Updates multiple LaunchConfigurations by Source Server ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.update_launch_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.update_launch_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_launch_configuration)
         """
 
@@ -374,25 +374,25 @@ class mgnClient(BaseClient):
         self,
         *,
         sourceServerID: str,
-        associateDefaultSecurityGroup: bool = None,
-        bandwidthThrottling: int = None,
-        createPublicIP: bool = None,
-        dataPlaneRouting: ReplicationConfigurationDataPlaneRoutingType = None,
-        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskTypeType = None,
-        ebsEncryption: ReplicationConfigurationEbsEncryptionType = None,
-        ebsEncryptionKeyArn: str = None,
-        name: str = None,
-        replicatedDisks: List["ReplicationConfigurationReplicatedDiskTypeDef"] = None,
-        replicationServerInstanceType: str = None,
-        replicationServersSecurityGroupsIDs: List[str] = None,
-        stagingAreaSubnetId: str = None,
-        stagingAreaTags: Dict[str, str] = None,
-        useDedicatedReplicationServer: bool = None
+        associateDefaultSecurityGroup: bool = ...,
+        bandwidthThrottling: int = ...,
+        createPublicIP: bool = ...,
+        dataPlaneRouting: ReplicationConfigurationDataPlaneRoutingType = ...,
+        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskTypeType = ...,
+        ebsEncryption: ReplicationConfigurationEbsEncryptionType = ...,
+        ebsEncryptionKeyArn: str = ...,
+        name: str = ...,
+        replicatedDisks: Sequence["ReplicationConfigurationReplicatedDiskTypeDef"] = ...,
+        replicationServerInstanceType: str = ...,
+        replicationServersSecurityGroupsIDs: Sequence[str] = ...,
+        stagingAreaSubnetId: str = ...,
+        stagingAreaTags: Mapping[str, str] = ...,
+        useDedicatedReplicationServer: bool = ...
     ) -> ReplicationConfigurationTypeDef:
         """
         Allows you to update multiple ReplicationConfigurations by Source Server ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.update_replication_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.update_replication_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_replication_configuration)
         """
 
@@ -400,24 +400,24 @@ class mgnClient(BaseClient):
         self,
         *,
         replicationConfigurationTemplateID: str,
-        arn: str = None,
-        associateDefaultSecurityGroup: bool = None,
-        bandwidthThrottling: int = None,
-        createPublicIP: bool = None,
-        dataPlaneRouting: ReplicationConfigurationDataPlaneRoutingType = None,
-        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskTypeType = None,
-        ebsEncryption: ReplicationConfigurationEbsEncryptionType = None,
-        ebsEncryptionKeyArn: str = None,
-        replicationServerInstanceType: str = None,
-        replicationServersSecurityGroupsIDs: List[str] = None,
-        stagingAreaSubnetId: str = None,
-        stagingAreaTags: Dict[str, str] = None,
-        useDedicatedReplicationServer: bool = None
+        arn: str = ...,
+        associateDefaultSecurityGroup: bool = ...,
+        bandwidthThrottling: int = ...,
+        createPublicIP: bool = ...,
+        dataPlaneRouting: ReplicationConfigurationDataPlaneRoutingType = ...,
+        defaultLargeStagingDiskType: ReplicationConfigurationDefaultLargeStagingDiskTypeType = ...,
+        ebsEncryption: ReplicationConfigurationEbsEncryptionType = ...,
+        ebsEncryptionKeyArn: str = ...,
+        replicationServerInstanceType: str = ...,
+        replicationServersSecurityGroupsIDs: Sequence[str] = ...,
+        stagingAreaSubnetId: str = ...,
+        stagingAreaTags: Mapping[str, str] = ...,
+        useDedicatedReplicationServer: bool = ...
     ) -> ReplicationConfigurationTemplateResponseMetadataTypeDef:
         """
         Updates multiple ReplicationConfigurationTemplates by ID.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Client.update_replication_configuration_template)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Client.update_replication_configuration_template)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/client.html#update_replication_configuration_template)
         """
 
@@ -426,14 +426,14 @@ class mgnClient(BaseClient):
         self, operation_name: Literal["describe_job_log_items"]
     ) -> DescribeJobLogItemsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeJobLogItems)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejoblogitemspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_jobs"]) -> DescribeJobsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Paginator.DescribeJobs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeJobs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describejobspaginator)
         """
 
@@ -442,7 +442,7 @@ class mgnClient(BaseClient):
         self, operation_name: Literal["describe_replication_configuration_templates"]
     ) -> DescribeReplicationConfigurationTemplatesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeReplicationConfigurationTemplates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describereplicationconfigurationtemplatespaginator)
         """
 
@@ -451,6 +451,6 @@ class mgnClient(BaseClient):
         self, operation_name: Literal["describe_source_servers"]
     ) -> DescribeSourceServersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.21/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/mgn.html#mgn.Paginator.DescribeSourceServers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mgn/paginators.html#describesourceserverspaginator)
         """
