@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     ChangeServerLifeCycleStateSourceServerLifecycleStateType,
@@ -35,7 +35,7 @@ from .literals import (
     TargetInstanceTypeRightSizingMethodType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -148,9 +148,9 @@ _RequiredCreateReplicationConfigurationTemplateRequestRequestTypeDef = TypedDict
         "defaultLargeStagingDiskType": ReplicationConfigurationDefaultLargeStagingDiskTypeType,
         "ebsEncryption": ReplicationConfigurationEbsEncryptionType,
         "replicationServerInstanceType": str,
-        "replicationServersSecurityGroupsIDs": List[str],
+        "replicationServersSecurityGroupsIDs": Sequence[str],
         "stagingAreaSubnetId": str,
-        "stagingAreaTags": Dict[str, str],
+        "stagingAreaTags": Mapping[str, str],
         "useDedicatedReplicationServer": bool,
     },
 )
@@ -158,7 +158,7 @@ _OptionalCreateReplicationConfigurationTemplateRequestRequestTypeDef = TypedDict
     "_OptionalCreateReplicationConfigurationTemplateRequestRequestTypeDef",
     {
         "ebsEncryptionKeyArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -281,7 +281,7 @@ DescribeJobsRequestFiltersTypeDef = TypedDict(
     "DescribeJobsRequestFiltersTypeDef",
     {
         "fromDate": str,
-        "jobIDs": List[str],
+        "jobIDs": Sequence[str],
         "toDate": str,
     },
     total=False,
@@ -321,7 +321,7 @@ DescribeJobsResponseTypeDef = TypedDict(
 _RequiredDescribeReplicationConfigurationTemplatesRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeReplicationConfigurationTemplatesRequestRequestTypeDef",
     {
-        "replicationConfigurationTemplateIDs": List[str],
+        "replicationConfigurationTemplateIDs": Sequence[str],
     },
 )
 _OptionalDescribeReplicationConfigurationTemplatesRequestRequestTypeDef = TypedDict(
@@ -354,7 +354,7 @@ DescribeSourceServersRequestFiltersTypeDef = TypedDict(
     "DescribeSourceServersRequestFiltersTypeDef",
     {
         "isArchived": bool,
-        "sourceServerIDs": List[str],
+        "sourceServerIDs": Sequence[str],
     },
     total=False,
 )
@@ -818,13 +818,13 @@ SourceServerTypeDef = TypedDict(
 _RequiredStartCutoverRequestRequestTypeDef = TypedDict(
     "_RequiredStartCutoverRequestRequestTypeDef",
     {
-        "sourceServerIDs": List[str],
+        "sourceServerIDs": Sequence[str],
     },
 )
 _OptionalStartCutoverRequestRequestTypeDef = TypedDict(
     "_OptionalStartCutoverRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -847,13 +847,13 @@ StartCutoverResponseTypeDef = TypedDict(
 _RequiredStartTestRequestRequestTypeDef = TypedDict(
     "_RequiredStartTestRequestRequestTypeDef",
     {
-        "sourceServerIDs": List[str],
+        "sourceServerIDs": Sequence[str],
     },
 )
 _OptionalStartTestRequestRequestTypeDef = TypedDict(
     "_OptionalStartTestRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -877,20 +877,20 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
 _RequiredTerminateTargetInstancesRequestRequestTypeDef = TypedDict(
     "_RequiredTerminateTargetInstancesRequestRequestTypeDef",
     {
-        "sourceServerIDs": List[str],
+        "sourceServerIDs": Sequence[str],
     },
 )
 _OptionalTerminateTargetInstancesRequestRequestTypeDef = TypedDict(
     "_OptionalTerminateTargetInstancesRequestRequestTypeDef",
     {
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -915,7 +915,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -963,11 +963,11 @@ _OptionalUpdateReplicationConfigurationRequestRequestTypeDef = TypedDict(
         "ebsEncryption": ReplicationConfigurationEbsEncryptionType,
         "ebsEncryptionKeyArn": str,
         "name": str,
-        "replicatedDisks": List["ReplicationConfigurationReplicatedDiskTypeDef"],
+        "replicatedDisks": Sequence["ReplicationConfigurationReplicatedDiskTypeDef"],
         "replicationServerInstanceType": str,
-        "replicationServersSecurityGroupsIDs": List[str],
+        "replicationServersSecurityGroupsIDs": Sequence[str],
         "stagingAreaSubnetId": str,
-        "stagingAreaTags": Dict[str, str],
+        "stagingAreaTags": Mapping[str, str],
         "useDedicatedReplicationServer": bool,
     },
     total=False,
@@ -999,9 +999,9 @@ _OptionalUpdateReplicationConfigurationTemplateRequestRequestTypeDef = TypedDict
         "ebsEncryption": ReplicationConfigurationEbsEncryptionType,
         "ebsEncryptionKeyArn": str,
         "replicationServerInstanceType": str,
-        "replicationServersSecurityGroupsIDs": List[str],
+        "replicationServersSecurityGroupsIDs": Sequence[str],
         "stagingAreaSubnetId": str,
-        "stagingAreaTags": Dict[str, str],
+        "stagingAreaTags": Mapping[str, str],
         "useDedicatedReplicationServer": bool,
     },
     total=False,
